summaryrefslogtreecommitdiffstats
path: root/kplato/kptsummarytaskdialog.h
diff options
context:
space:
mode:
Diffstat (limited to 'kplato/kptsummarytaskdialog.h')
-rw-r--r--kplato/kptsummarytaskdialog.h17
1 files changed, 9 insertions, 8 deletions
diff --git a/kplato/kptsummarytaskdialog.h b/kplato/kptsummarytaskdialog.h
index e307fea9..d1607783 100644
--- a/kplato/kptsummarytaskdialog.h
+++ b/kplato/kptsummarytaskdialog.h
@@ -31,12 +31,12 @@ class KTextEdit;
class KComboBox;
class KDoubleNumInput;
-class QDateTimeEdit;
-class QSpinBox;
-class QButtonGroup;
-class QListBox;
-class QTable;
-class QDateTime;
+class TQDateTimeEdit;
+class TQSpinBox;
+class TQButtonGroup;
+class TQListBox;
+class TQTable;
+class TQDateTime;
namespace KPlato
{
@@ -50,13 +50,14 @@ class Task;
*/
class SummaryTaskDialog : public KDialogBase {
Q_OBJECT
+ TQ_OBJECT
public:
/**
* The constructor for the summary task settings dialog.
* @param task the task to edit
* @param parent parent widget
*/
- SummaryTaskDialog(Task &task, QWidget *parent=0);
+ SummaryTaskDialog(Task &task, TQWidget *tqparent=0);
KCommand *buildCommand(Part *part);
@@ -50,13 +50,14 @@ class Task;
* The constructor for the summary task settings dialog.
* @param task the task to edit
- * @param parent parent widget
+ * @param tqparent tqparent widget
*/